@@ -37,7 +37,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.9.6"
+#define LIBGNUTLS_VERSION "0.9.7"
 
 /* For backwards compatibility */
 #include <gnutls/compat4.h>
@@ -550,8 +550,10 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 #define GNUTLS_E_EXPIRED -29
 #define GNUTLS_E_DB_ERROR -30
 #define GNUTLS_E_SRP_PWD_ERROR -31
-#define GNUTLS_E_INSUFICIENT_CREDENTIALS -32
-#define GNUTLS_E_INSUFICIENT_CRED GNUTLS_E_INSUFICIENT_CREDENTIALS
+#define GNUTLS_E_INSUFFICIENT_CREDENTIALS -32
+#define GNUTLS_E_INSUFICIENT_CREDENTIALS GNUTLS_E_INSUFFICIENT_CREDENTIALS /* for backwards compatibility only */
+#define GNUTLS_E_INSUFFICIENT_CRED GNUTLS_E_INSUFFICIENT_CREDENTIALS
+#define GNUTLS_E_INSUFICIENT_CRED GNUTLS_E_INSUFFICIENT_CREDENTIALS /* for backwards compatibility only */
 
 #define GNUTLS_E_HASH_FAILED -33
 #define GNUTLS_E_BASE64_DECODING_ERROR -34
@@ -636,7 +638,10 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 #define GNUTLS_E_INVALID_PASSWORD -99
 #define GNUTLS_E_MAC_VERIFY_FAILED -100 /* for PKCS #12 MAC */
 
-#define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
+#define GNUTLS_E_BASE64_ENCODING_ERROR -201
+#define GNUTLS_E_INCOMPATIBLE_GCRYPT_LIBRARY -202
+
+#define GNUTLS_E_UNIMPLEMENTED_FEATURE -1250
 
 
 
