@@ -79,12 +79,13 @@ static gnutls_error_entry error_algorithms[] = {
 
 	ERROR_ENTRY("Internal error in memory allocation.", GNUTLS_E_MEMORY_ERROR, 1 ), 
 	ERROR_ENTRY("An unimplemented feature has been requested.", GNUTLS_E_UNIMPLEMENTED_FEATURE, 1 ), 
-	ERROR_ENTRY("Insuficient credentials for that request.", GNUTLS_E_INSUFICIENT_CREDENTIALS, 1 ), 
+	ERROR_ENTRY("Insufficient credentials for that request.", GNUTLS_E_INSUFFICIENT_CREDENTIALS, 1 ), 
 	ERROR_ENTRY("Error in SRP password file.", GNUTLS_E_SRP_PWD_ERROR, 1 ), 
 	ERROR_ENTRY("Wrong padding in PKCS1 packet.", GNUTLS_E_PKCS1_WRONG_PAD, 1 ), 
 	ERROR_ENTRY("The requested session has expired.", GNUTLS_E_EXPIRED, 1 ), 
 	ERROR_ENTRY("Hashing has failed.", GNUTLS_E_HASH_FAILED, 1 ), 
-	ERROR_ENTRY("Certificate parsing error.", GNUTLS_E_BASE64_DECODING_ERROR, 1 ), 
+	ERROR_ENTRY("Base64 decoding error.", GNUTLS_E_BASE64_DECODING_ERROR, 1 ), 
+	ERROR_ENTRY("Base64 encoding error.", GNUTLS_E_BASE64_ENCODING_ERROR, 1 ), 
 	ERROR_ENTRY("Parsing error in SRP password file.", GNUTLS_E_SRP_PWD_PARSING_ERROR, 1 ), 
 	ERROR_ENTRY("The requested data, were not available.", GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE, 0 ), 
 	ERROR_ENTRY("Error in the pull function.", GNUTLS_E_PULL_ERROR, 1 ), 
@@ -122,6 +123,8 @@ static gnutls_error_entry error_algorithms[] = {
 	ERROR_ENTRY("The initialization of GnuTLS-extra has failed.", GNUTLS_E_INIT_LIBEXTRA, 1 ), 
 	ERROR_ENTRY("The GnuTLS library version does not match the GnuTLS-extra library version.", 
 		GNUTLS_E_LIBRARY_VERSION_MISMATCH, 1 ), 
+	ERROR_ENTRY("The gcrypt library version is too old.", 
+		GNUTLS_E_INCOMPATIBLE_GCRYPT_LIBRARY, 1 ), 
 	ERROR_ENTRY("The specified GnuPG TrustDB version is not supported. TrustDB v4 is supported.", 
 		GNUTLS_E_OPENPGP_TRUSTDB_VERSION_UNSUPPORTED, 1 ),
 	ERROR_ENTRY("The initialization of LZO has failed.", GNUTLS_E_LZO_INIT_FAILED, 1 ), 
@@ -158,7 +161,7 @@ static gnutls_error_entry error_algorithms[] = {
   * If a function returns a negative value you may feed that value
   * to this function to see if it is fatal. Returns 1 for a fatal 
   * error 0 otherwise. However you may want to check the
-  * error code manualy, since some non-fatal errors to the protocol
+  * error code manually, since some non-fatal errors to the protocol
   * may be fatal for you (your program).
   *
   * This is only useful if you are dealing with errors from the
@@ -274,8 +277,6 @@ void _gnutls_log( int level, const char *fmt, ...) {
  va_end(args);   
 
  log_func( level, str);
-
- return;
 }
 #ifndef DEBUG
 # ifndef C99_MACROS
@@ -285,8 +286,6 @@ void _gnutls_log( int level, const char *fmt, ...) {
  */
 void _gnutls_null_log( void* x, ...) { return; }
 const char* _gnutls_handshake2str( int handshake) { return NULL; }
-char * _gnutls_bin2hex(const unsigned char *old, const size_t oldlen)
-	{ return NULL; }
 const char* _gnutls_packet2str( int packet) { return NULL; }
 
 # endif /* C99_MACROS */
