@@ -166,8 +166,6 @@ static void _gnutls_extension_list_add( gnutls_session session, uint16 type) {
 			_gnutls_debug_log("extensions: Increase MAX_EXT_TYPES\n");
 		}
 	}
-
-	return;
 }
 
 int _gnutls_gen_extensions( gnutls_session session, opaque** data) {
@@ -215,7 +213,7 @@ int (*ext_func_send)( gnutls_session, opaque*, int);
 			_gnutls_extension_list_add( session, next);
 		} else if (size < 0) {
 			gnutls_assert();
-			gnutls_free(*data);
+			gnutls_free(*data); *data = NULL;
 			return size;
 		}
 		
