@@ -23,6 +23,7 @@
 #include <gnutls_errors.h>
 #include <libtasn1.h>
 #include <gnutls_dh.h>
+#include "x509/rc2.h"
 
 typedef void (*LOG_FUNC)( int, const char*);
 #define gnutls_log_func LOG_FUNC
@@ -43,7 +44,7 @@ ASN1_TYPE _gnutls_gnutls_asn;
   *
   * This is the function where you set the logging function gnutls
   * is going to use. This function only accepts a character array.
-  * Normaly you may not use this function since it is only used 
+  * Normally you may not use this function since it is only used 
   * for debugging purposes.
   *
   * gnutls_log_func is of the form, 
@@ -95,7 +96,7 @@ int _gnutls_is_secure_mem_null( const void*);
   * @secure_alloc_func: This is the memory allocation function that will be used for sensitive data.
   * @is_secure_func: a function that returns 0 if the memory given is not secure. May be NULL.
   * @realloc_func: A realloc function
-  * @free_func: The function that frees allocated data.
+  * @free_func: The function that frees allocated data. Must accept a NULL pointer.
   *
   * This is the function were you set the memory allocation functions gnutls
   * is going to use. By default the libc's allocation functions (malloc(), free()),
@@ -116,7 +117,7 @@ void gnutls_global_set_mem_functions(
 	gnutls_realloc = gnutls_realloc_func;
 	gnutls_free = gnutls_free_func;
 
-	if (gnutls_is_secure_func==NULL)
+	if (gnutls_is_secure_func!=NULL)
 		_gnutls_is_secure_memory = gnutls_is_secure_func;
 	else
 		_gnutls_is_secure_memory = _gnutls_is_secure_mem_null;
@@ -131,7 +132,6 @@ void gnutls_global_set_mem_functions(
 		gnutls_strdup = _gnutls_strdup;
 		gnutls_calloc = _gnutls_calloc;
 	}
-	return;
 }
 
 #ifdef DEBUG
@@ -154,22 +154,25 @@ static int _gnutls_init = 0;
   * Returns zero on success.
   *
   * Note that this function will also initialize libgcrypt, if it has not
-  * been initialized before. Thus if you want to manualy initialize libgcrypt
+  * been initialized before. Thus if you want to manually initialize libgcrypt
   * you must do it before calling this function. This is useful in cases you 
   * want to disable libgcrypt's internal lockings etc.
   *
   **/
 int gnutls_global_init( void)
 {
-	int result;
+	static int result = 0;
+	int res;
 
+	if (_gnutls_init) goto out;
 	_gnutls_init++;
 
-	if (_gnutls_init!=1) {
-		return 0;
-	}
-
 	if (gcry_control( GCRYCTL_ANY_INITIALIZATION_P) == 0) {
+		if (gcry_check_version(GNUTLS_GCRYPT_VERSION)==NULL) {
+			gnutls_assert();
+			return GNUTLS_E_INCOMPATIBLE_GCRYPT_LIBRARY;
+		}
+
 		/* for gcrypt in order to be able to allocate memory */
 		gcry_set_allocation_handler(gnutls_malloc, gnutls_secure_malloc, _gnutls_is_secure_memory, gnutls_realloc, gnutls_free);
 		
@@ -184,9 +187,13 @@ int gnutls_global_init( void)
 		gcry_set_log_handler( _gnutls_gcry_log_handler, NULL);
 #endif
 	}
-	
-	/* set default recv/send functions
-	 */
+
+	result = _gnutls_register_rc2_cipher();
+	if (result < 0) {
+		gnutls_assert();
+		goto out;
+	}
+
 #ifdef DEBUG
 	gnutls_global_set_log_function( dlog);
 #endif
@@ -196,18 +203,21 @@ int gnutls_global_init( void)
 	 * version.
 	 */
 	
-	result=asn1_array2tree( pkix_asn1_tab, &_gnutls_pkix1_asn, NULL);
-	if (result != ASN1_SUCCESS) {
-		return _gnutls_asn2err(result);
+	res=asn1_array2tree( pkix_asn1_tab, &_gnutls_pkix1_asn, NULL);
+	if (res != ASN1_SUCCESS) {
+		result = _gnutls_asn2err(res);
+		goto out;
 	}
 
-	result=asn1_array2tree( gnutls_asn1_tab, &_gnutls_gnutls_asn, NULL);
-	if (result != ASN1_SUCCESS) {
+	res=asn1_array2tree( gnutls_asn1_tab, &_gnutls_gnutls_asn, NULL);
+	if (res != ASN1_SUCCESS) {
 		asn1_delete_structure(&_gnutls_pkix1_asn);
-		return _gnutls_asn2err(result);
+		result = _gnutls_asn2err(res);
+		goto out;
 	}
 
-	return 0;
+	out:
+	return result;
 }
 
 /**
@@ -220,11 +230,12 @@ int gnutls_global_init( void)
 
 void gnutls_global_deinit( void) {
 
-	_gnutls_init--;
-
-	if (_gnutls_init==0) {
+	if (_gnutls_init==1) {
+		_gnutls_init--;
 		asn1_delete_structure(&_gnutls_gnutls_asn);
 		asn1_delete_structure(&_gnutls_pkix1_asn);
+
+		_gnutls_unregister_rc2_cipher();
 	}
 	
 }
@@ -240,7 +251,7 @@ void gnutls_global_deinit( void) {
   * @session: gnutls session
   *
   * This is the function where you set a function for gnutls 
-  * to receive data. Normaly, if you use berkeley style sockets,
+  * to receive data. Normally, if you use berkeley style sockets,
   * you may not use this function since the default (recv(2)) will 
   * probably be ok.
   * This function should be called once and after gnutls_global_init().
@@ -348,3 +359,4 @@ gnutls_check_version( const char *req_version )
     }
     return NULL;
 }
+
