@@ -112,8 +112,6 @@ static void resume_copy_required_values(gnutls_session session)
 	session->security_parameters.session_id_size =
 	    session->internals.resumed_security_parameters.
 	    session_id_size;
-
-	return;
 }
 
 void _gnutls_set_server_random(gnutls_session session, uint8 * random)
@@ -227,7 +225,7 @@ int _gnutls_create_random(opaque * dst)
 		gnutls_assert();
 		return GNUTLS_E_MEMORY_ERROR;
 	}
-	memcpy(&dst[4], rand, 28);
+	memcpy(&dst[4], rand, TLS_RANDOM_SIZE - 4);
 
 	return 0;
 }
@@ -241,9 +239,8 @@ int _gnutls_create_random(opaque * dst)
 int _gnutls_read_client_hello(gnutls_session session, opaque * data,
 			      int datalen)
 {
-	uint8 session_id_len = 0, z;
-	int pos = 0;
-	int ret = 0;
+	uint8 session_id_len, z;
+	int pos = 0, ret;
 	uint16 sizeOfSuites;
 	gnutls_protocol_version version;
 	int len = datalen;
@@ -310,7 +307,7 @@ int _gnutls_read_client_hello(gnutls_session session, opaque * data,
 		session->internals.resumed = RESUME_FALSE;
 	}
 
-	/* Select a ciphersuite 
+	/* Remember ciphersuites for later
 	 */
 	DECR_LEN(len, 2);
 	sizeOfSuites = _gnutls_read_uint16(&data[pos]);
@@ -394,13 +391,13 @@ char * data;
 int _gnutls_send_finished(gnutls_session session, int again)
 {
 	uint8 data[36];
-	int ret=0;
+	int ret;
 	int data_size = 0;
 
 
 	if (again == 0) {
 
-		/* This needed in order to hash all the required
+		/* This is needed in order to hash all the required
 		 * messages.
 		 */
 		if ((ret=_gnutls_handshake_hash_pending(session)) < 0) {
@@ -422,11 +419,12 @@ int _gnutls_send_finished(gnutls_session session, int again)
 					     entity, data);
 			data_size = 12;
 		}
-	}
 
-	if (ret < 0) {
-		gnutls_assert();
-		return ret;
+		if (ret < 0) {
+			gnutls_assert();
+			return ret;
+		}
+
 	}
 
 	ret =
@@ -446,8 +444,6 @@ int _gnutls_recv_finished(gnutls_session session)
 	int ret;
 	int vrfysize;
 
-	ret = 0;
-
 	ret =
 	    _gnutls_recv_handshake(session, &vrfy, &vrfysize,
 				   GNUTLS_FINISHED, MANDATORY_PACKET);
@@ -466,6 +462,7 @@ int _gnutls_recv_finished(gnutls_session session)
 
 	if (vrfysize != data_size) {
 		gnutls_assert();
+		gnutls_free(vrfy);
 		return GNUTLS_E_ERROR_IN_FINISHED_PACKET;
 	}
 
@@ -483,6 +480,7 @@ int _gnutls_recv_finished(gnutls_session session)
 
 	if (ret < 0) {
 		gnutls_assert();
+		gnutls_free(vrfy);
 		return ret;
 	}
 
@@ -518,8 +516,8 @@ gnutls_kx_algorithm kx;
 }
 
 
-/* This selects the best supported ciphersuite from the ones supported. Then
- * it adds the suite into the session and performs some checks. 
+/* This selects the best supported ciphersuite from the given ones. Then
+ * it adds the suite to the session and performs some checks.
  */
 int _gnutls_server_select_suite(gnutls_session session, opaque *data, int datalen)
 {
@@ -540,11 +538,12 @@ int _gnutls_server_select_suite(gnutls_session session, opaque *data, int datale
 
 	/* Here we remove any ciphersuite that does not conform
 	 * the certificate requested, or to the
-	 * authentication requested (eg SRP).
+	 * authentication requested (e.g. SRP).
 	 */
 	x = _gnutls_remove_unwanted_ciphersuites(session, &ciphers, x, pk_algo);
 	if (x<=0) {
 		gnutls_assert();
+		gnutls_free(ciphers);
 		if (x<0) return x;
 		else return GNUTLS_E_UNKNOWN_CIPHER_SUITE;
 	}
@@ -586,14 +585,14 @@ int _gnutls_server_select_suite(gnutls_session session, opaque *data, int datale
 		return retval;
 	}
 	
-	/* check if the credentials (username, public key etc. are ok)
+	/* check if the credentials (username, public key etc.) are ok
 	 */
 	if (_gnutls_get_kx_cred
 	    (session, _gnutls_cipher_suite_get_kx_algo(session->security_parameters.
 					      current_cipher_suite),
 	     &err) == NULL && err != 0) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 
@@ -624,24 +623,24 @@ int _gnutls_server_select_comp_method(gnutls_session session, opaque * data,
 				    int datalen)
 {
 	int x, i, j;
-	uint8 *ciphers;
+	uint8 *comps;
 
-	x = _gnutls_supported_compression_methods(session, &ciphers);
+	x = _gnutls_supported_compression_methods(session, &comps);
 	if (x < 0) {
 		gnutls_assert();
 		return x;
 	}
 
-	memset( &session->internals.compression_method, '\0', sizeof(gnutls_compression_method));
+	memset( &session->internals.compression_method, 0, sizeof(gnutls_compression_method));
 
 	for (j = 0; j < datalen; j++) {
 		for (i = 0; i < x; i++) {
-			if (ciphers[i] == data[j]) {
+			if (comps[i] == data[j]) {
 			        gnutls_compression_method method = 
-				    _gnutls_compression_get_id(ciphers[i]);
+				    _gnutls_compression_get_id(comps[i]);
 
 				session->internals.compression_method = method;
-				gnutls_free(ciphers);
+				gnutls_free(comps);
 
 				_gnutls_handshake_log("HSK: Selected Compression Method: %s\n",
 				    gnutls_compression_get_name(session->internals.
@@ -656,7 +655,7 @@ int _gnutls_server_select_comp_method(gnutls_session session, opaque * data,
 	/* we were not able to find a compatible compression
 	 * algorithm
 	 */
-	gnutls_free(ciphers);
+	gnutls_free(comps);
 	gnutls_assert();
 	return GNUTLS_E_UNKNOWN_COMPRESSION_ALGORITHM;
 
@@ -769,7 +768,7 @@ int _gnutls_send_handshake(gnutls_session session, void *i_data,
 	return ret;
 }
 
-/* This function will read the handshake header, and return it to the called. If the
+/* This function will read the handshake header and return it to the caller. If the
  * received handshake packet is not the one expected then it buffers the header, and
  * returns UNEXPECTED_HANDSHAKE_PACKET.
  *
@@ -818,11 +817,12 @@ static int _gnutls_recv_handshake_header(gnutls_session session,
 					       SSL2_HEADERS);
 
 		if (ret < 0) {
-			return (ret <
-				0) ? ret :
-			    GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
+			gnutls_assert();
+			return ret;
 		}
 
+		/* The case ret==0 is caught here.
+		 */
 		if (ret != SSL2_HEADERS) {
 			gnutls_assert();
 			return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
@@ -949,8 +949,8 @@ int ret;
 
 /* This function will receive handshake messages of the given types,
  * and will pass the message to the right place in order to be processed.
- * Eg. for the SERVER_HELLO message (if it is expected), it will be
- * send to _gnutls_recv_hello().
+ * E.g. for the SERVER_HELLO message (if it is expected), it will be
+ * passed to _gnutls_recv_hello().
  */
 int _gnutls_recv_handshake(gnutls_session session, uint8 ** data,
 			   int *datalen, HandshakeType type,
@@ -965,8 +965,10 @@ int _gnutls_recv_handshake(gnutls_session session, uint8 ** data,
 	if (ret < 0) {
 		if (ret == GNUTLS_E_UNEXPECTED_HANDSHAKE_PACKET
 		    && optional == OPTIONAL_PACKET) {
-			*datalen = 0;
-			*data = NULL;
+			if (datalen != NULL)
+				*datalen = 0;
+			if (data != NULL)
+				*data = NULL;
 			return 0;	/* ok just ignore the packet */
 		}
 		/* gnutls_assert(); */
@@ -1005,9 +1007,6 @@ int _gnutls_recv_handshake(gnutls_session session, uint8 ** data,
 		}
 	}
 
-
-	ret = GNUTLS_E_INTERNAL_ERROR;
-
 	if (data != NULL && length32 > 0)
 		*data = dataptr;
 
@@ -1034,6 +1033,7 @@ int _gnutls_recv_handshake(gnutls_session session, uint8 ** data,
 		/* dataptr is freed because the caller does not
 		 * need it */
 		gnutls_free(dataptr);
+		if (data!=NULL) *data = NULL;
 		break;
 	case GNUTLS_SERVER_HELLO_DONE:
 		if (length32==0) ret = 0;
@@ -1077,7 +1077,7 @@ static int _gnutls_client_set_ciphersuite(gnutls_session session,
 	
 	for (i = 0; i < cipher_suite_num; i++) {
 		if (memcmp(&cipher_suites[i], suite, 2) == 0) {
-			z = 0;
+			z = 0; break;
 		}
 	}
 
@@ -1098,7 +1098,7 @@ static int _gnutls_client_set_ciphersuite(gnutls_session session,
 						  current_cipher_suite));
 
 
-	/* check if the credentials (username, public key etc. are ok). 
+	/* check if the credentials (username, public key etc.) are ok.
 	 * Actually checks if they exist.
 	 */
 	if (_gnutls_get_kx_cred
@@ -1107,7 +1107,7 @@ static int _gnutls_client_set_ciphersuite(gnutls_session session,
 					      current_cipher_suite),
 	     &err) == NULL && err != 0) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 
@@ -1150,7 +1150,7 @@ static int _gnutls_client_set_comp_method(gnutls_session session,
 	
 	for (i = 0; i < comp_methods_num; i++) {
 		if (compression_methods[i] == comp_method) {
-			comp_methods_num = 0;
+			comp_methods_num = 0; break;
 		}
 	}
 
@@ -1213,7 +1213,7 @@ char buf[64];
 }
 
 
-/* This function read and parse the server hello handshake message.
+/* This function reads and parses the server hello handshake message.
  * This function also restores resumed parameters if we are resuming a
  * session.
  */
@@ -1307,7 +1307,7 @@ static int _gnutls_read_server_hello(gnutls_session session, char *data,
 }
 
 
-/* This function copies the appropriate ciphersuites, to a localy allocated buffer 
+/* This function copies the appropriate ciphersuites to a locally allocated buffer
  * Needed in client hello messages. Returns the new data length.
  */
 static int _gnutls_copy_ciphersuites(gnutls_session session,
@@ -1333,6 +1333,7 @@ static int _gnutls_copy_ciphersuites(gnutls_session session,
 						 ret, -1);
 	if (ret < 0) {
 		gnutls_assert();
+		gnutls_free(cipher_suites);
 		return ret;
 	}
 
@@ -1340,7 +1341,8 @@ static int _gnutls_copy_ciphersuites(gnutls_session session,
 	 */
 	if (ret == 0) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		gnutls_free(cipher_suites);
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 	cipher_num = ret;
@@ -1354,6 +1356,7 @@ static int _gnutls_copy_ciphersuites(gnutls_session session,
 	*ret_data = gnutls_malloc(datalen);
 	if (*ret_data == NULL) {
 		gnutls_assert();
+		gnutls_free(cipher_suites);
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 
@@ -1371,7 +1374,7 @@ static int _gnutls_copy_ciphersuites(gnutls_session session,
 }
 
 
-/* This function copies the appropriate compression methods, to a localy allocated buffer 
+/* This function copies the appropriate compression methods, to a locally allocated buffer 
  * Needed in hello messages. Returns the new data length.
  */
 static int _gnutls_copy_comp_methods(gnutls_session session,
@@ -1397,6 +1400,7 @@ static int _gnutls_copy_comp_methods(gnutls_session session,
 	*ret_data = gnutls_malloc(datalen);
 	if (*ret_data == NULL) {
 		gnutls_assert();
+		gnutls_free(compression_methods);
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 
@@ -1419,7 +1423,7 @@ static int _gnutls_send_client_hello(gnutls_session session, int again)
 	opaque *extdata = NULL;
 	int extdatalen;
 	int pos = 0;
-	int datalen, ret = 0;
+	int datalen = 0, ret = 0;
 	opaque random[TLS_RANDOM_SIZE];
 	gnutls_protocol_version hver;
 
@@ -1429,13 +1433,9 @@ static int _gnutls_send_client_hello(gnutls_session session, int again)
 	    session->internals.resumed_security_parameters.
 	    session_id_size;
 
-	if (SessionID == NULL || session_id_len == 0) {
-		session_id_len = 0;
-		SessionID = NULL;
-	}
+	if (SessionID == NULL) session_id_len = 0;
+	else if (session_id_len == 0) SessionID = NULL;
 
-	data = NULL;
-	datalen = 0;
 	if (again == 0) {
 
 		datalen = 2 + (session_id_len + 1) + TLS_RANDOM_SIZE;
@@ -1463,6 +1463,7 @@ static int _gnutls_send_client_hello(gnutls_session session, int again)
 			if (hver == 0)
 				hver = GNUTLS_E_INTERNAL_ERROR;
 			gnutls_assert();
+			gnutls_free(data);
 			return hver;
 		}
 
@@ -1573,7 +1574,6 @@ static int _gnutls_send_client_hello(gnutls_session session, int again)
 				gnutls_free(extdata);
 			} else if (extdatalen < 0) {
 				gnutls_assert();
-				gnutls_free(extdata);
 				gnutls_free(data);
 				return extdatalen;
 			}
@@ -1611,7 +1611,6 @@ static int _gnutls_send_server_hello(gnutls_session session, int again)
 
 		if (extdatalen < 0) {
 			gnutls_assert();
-			gnutls_free(extdata);
 			return extdatalen;
 		}
 
@@ -1815,8 +1814,8 @@ static int _gnutls_handshake_hash_init( gnutls_session session) {
 }		
 
 /**
-  * gnutls_handshake - This the main function in the handshake protocol.
-  * @session: is a a &gnutls_session structure.
+  * gnutls_handshake - This is the main function in the handshake protocol.
+  * @session: is a &gnutls_session structure.
   *
   * This function does the handshake of the TLS/SSL protocol,
   * and initializes the TLS connection. 
@@ -1826,9 +1825,10 @@ static int _gnutls_handshake_hash_init( gnutls_session session) {
   * if it has been asked to resume a session, but the server didn't, then
   * a full handshake will be performed.
   *
-  * This function may also return the non-fatal errors GNUTLS_E_AGAIN, or 
-  * GNUTLS_E_INTERRUPTED. In that case you may resume the handshake
-  * (call this function again, until it returns ok)
+  * This function may also return the non-fatal errors GNUTLS_E_AGAIN and
+  * GNUTLS_E_INTERRUPTED; in that case you may resume the handshake
+  * (call this function again, until it returns ok); cf.
+  * gnutls_record_get_direction().
   *
   * If this function is called by a server after a rehandshake request then
   * GNUTLS_E_GOT_APPLICATION_DATA or GNUTLS_E_WARNING_ALERT_RECEIVED 
@@ -1876,14 +1876,14 @@ int gnutls_handshake(gnutls_session session)
 	return 0;
 }
 
-#define IMED_RET( str, ret) \
+#define IMED_RET( str, ret) do { \
 	if (ret < 0) { \
 		if (gnutls_error_is_fatal(ret)==0) return ret; \
 		gnutls_assert(); \
 		ERR( str, ret); \
 		_gnutls_handshake_hash_buffers_clear(session); \
 		return ret; \
-	}
+	} } while (0)
 
 
 
@@ -2281,7 +2281,7 @@ int _gnutls_recv_hello_request(gnutls_session session, void *data,
 }
 
 /* This function will remove algorithms that are not supported by
- * the requested authentication method. We remove algorithm if
+ * the requested authentication method. We remove an algorithm if
  * we have a certificate with keyUsage bits set.
  *
  * This does a more high level check than  gnutls_supported_ciphersuites(),
