@@ -31,14 +31,15 @@
 GNUTLS_HASH_HANDLE _gnutls_hash_init(gnutls_mac_algorithm algorithm)
 {
 	GNUTLS_MAC_HANDLE ret;
+	gcry_error_t result;
 
 	switch (algorithm) {
 	case GNUTLS_MAC_SHA:
 		ret = gnutls_malloc(sizeof(GNUTLS_MAC_HANDLE_INT));
 		if (ret == NULL)
 			return GNUTLS_HASH_FAILED;
-		ret->handle = gcry_md_open(GCRY_MD_SHA1, 0);
-		if (!ret->handle) {
+		result = gcry_md_open( &ret->handle, GCRY_MD_SHA1, 0);
+		if (result) {
 			gnutls_free(ret);
 			ret = GNUTLS_HASH_FAILED;
 		}
@@ -48,15 +49,15 @@ GNUTLS_HASH_HANDLE _gnutls_hash_init(gnutls_mac_algorithm algorithm)
 		ret = gnutls_malloc(sizeof(GNUTLS_MAC_HANDLE_INT));
 		if (ret == NULL)
 			return GNUTLS_HASH_FAILED;
-		ret->handle = gcry_md_open(GCRY_MD_MD5, 0);
-		if (!ret->handle) {
+		result = gcry_md_open( &ret->handle, GCRY_MD_MD5, 0);
+		if (result) {
 			gnutls_free(ret);
 			ret = GNUTLS_HASH_FAILED;
 		}
 		break;
 
 	default:
-		ret = GNUTLS_HASH_FAILED;
+		ret = GNUTLS_HASH_FAILED; break;
 	}
 
 	if (ret != GNUTLS_HASH_FAILED)
@@ -77,7 +78,7 @@ int _gnutls_hash_get_algo_len(gnutls_mac_algorithm algorithm)
 		ret = gcry_md_get_algo_dlen(GCRY_MD_MD5);
 		break;
 	default:
-		ret = 0;
+		ret = 0; break;
 	}
 
 	return ret;
@@ -94,6 +95,7 @@ int _gnutls_hash(GNUTLS_HASH_HANDLE handle, const void *text, size_t textlen)
 GNUTLS_HASH_HANDLE _gnutls_hash_copy(GNUTLS_HASH_HANDLE handle)
 {
 	GNUTLS_HASH_HANDLE ret;
+	gcry_error_t result;
 
 	ret = gnutls_malloc(sizeof(GNUTLS_MAC_HANDLE_INT));
 
@@ -104,9 +106,9 @@ GNUTLS_HASH_HANDLE _gnutls_hash_copy(GNUTLS_HASH_HANDLE handle)
 	ret->key = NULL;	/* it's a hash anyway */
 	ret->keysize = 0;
 
-	ret->handle = gcry_md_copy(handle->handle);
+	result = gcry_md_copy( &ret->handle, handle->handle);
 
-	if (ret->handle == NULL) {
+	if (result) {
 		gnutls_free(ret);
 		return GNUTLS_HASH_FAILED;
 	}
@@ -129,7 +131,6 @@ void _gnutls_hash_deinit(GNUTLS_HASH_HANDLE handle, void *digest)
 	gcry_md_close(handle->handle);
 
 	gnutls_free(handle);
-	return;
 }
 
 
@@ -137,20 +138,17 @@ GNUTLS_MAC_HANDLE _gnutls_hmac_init(gnutls_mac_algorithm algorithm,
 				    const void *key, int keylen)
 {
 	GNUTLS_MAC_HANDLE ret;
+	gcry_error_t result;
 
 	switch (algorithm) {
-	case GNUTLS_MAC_NULL:
-		ret = GNUTLS_MAC_FAILED;
-		break;
 	case GNUTLS_MAC_SHA:
 		ret = gnutls_malloc(sizeof(GNUTLS_MAC_HANDLE_INT));
 		if (ret == NULL)
 			return GNUTLS_MAC_FAILED;
 
-		ret->handle =
-		    gcry_md_open(GCRY_MD_SHA1, GCRY_MD_FLAG_HMAC);
+		result = gcry_md_open(&ret->handle, GCRY_MD_SHA1, GCRY_MD_FLAG_HMAC);
 
-		if (!ret->handle)
+		if (result)
 			ret = GNUTLS_MAC_FAILED;
 		break;
 	case GNUTLS_MAC_MD5:
@@ -158,9 +156,9 @@ GNUTLS_MAC_HANDLE _gnutls_hmac_init(gnutls_mac_algorithm algorithm,
 		if (ret == NULL)
 			return GNUTLS_MAC_FAILED;
 
-		ret->handle = gcry_md_open(GCRY_MD_MD5, GCRY_MD_FLAG_HMAC);
+		result = gcry_md_open(&ret->handle, GCRY_MD_MD5, GCRY_MD_FLAG_HMAC);
 
-		if (!ret->handle)
+		if (result)
 			ret = GNUTLS_MAC_FAILED;
 		break;
 	default:
@@ -210,7 +208,6 @@ void _gnutls_hmac_deinit(GNUTLS_MAC_HANDLE handle, void *digest)
 	gcry_md_close(handle->handle);
 
 	gnutls_free(handle);
-	return;
 }
 
 GNUTLS_MAC_HANDLE _gnutls_mac_init_ssl3(gnutls_mac_algorithm algorithm, void *key,
@@ -280,7 +277,6 @@ void _gnutls_mac_deinit_ssl3(GNUTLS_MAC_HANDLE handle, void *digest)
 
 		_gnutls_hash_deinit(td, digest);
 	}
-	return;
 }
 
 void _gnutls_mac_deinit_ssl3_handshake(GNUTLS_MAC_HANDLE handle,
@@ -326,7 +322,6 @@ void _gnutls_mac_deinit_ssl3_handshake(GNUTLS_MAC_HANDLE handle,
 
 		_gnutls_hash_deinit(td, digest);
 	}
-	return;
 }
 
 static int ssl3_sha(int i, char *secret, int secret_len, char *random,
