@@ -19,13 +19,9 @@
  */
 
 int _gnutls_send_server_kx_message( gnutls_session session, int again);
-int _gnutls_send_server_kx_message2( gnutls_session session, int again);
 int _gnutls_send_client_kx_message( gnutls_session session, int again);
-int _gnutls_send_client_kx_message0( gnutls_session session, int again);
 int _gnutls_recv_server_kx_message( gnutls_session session);
-int _gnutls_recv_server_kx_message2( gnutls_session session);
 int _gnutls_recv_client_kx_message( gnutls_session session);
-int _gnutls_recv_client_kx_message0( gnutls_session session);
 int _gnutls_send_client_certificate_verify( gnutls_session session, int again);
 int _gnutls_send_server_certificate( gnutls_session session, int again);
 int _gnutls_generate_master( gnutls_session session);
