@@ -84,11 +84,13 @@ int _gnutls_pkcs1_rsa_encrypt(gnutls_datum * ciphertext,
 		/* using public key */
 		if (params_len < RSA_PUBLIC_PARAMS) {
 			gnutls_assert();
+			gnutls_free(edata);
 			return GNUTLS_E_INTERNAL_ERROR;
 		}
 		
 		if ( (ret=_gnutls_get_random(ps, psize, GNUTLS_STRONG_RANDOM)) < 0) {
 			gnutls_assert();
+			gnutls_free(edata);
 			return ret;
 		}
 		for (i = 0; i < psize; i++) {
@@ -99,6 +101,7 @@ int _gnutls_pkcs1_rsa_encrypt(gnutls_datum * ciphertext,
 			 */
 			if ( (ret=_gnutls_get_random( rnd, 3, GNUTLS_STRONG_RANDOM)) < 0) {
 				gnutls_assert();
+				gnutls_free(edata);
 				return ret;
 			}
 			/* use non zero values for 
@@ -123,6 +126,7 @@ int _gnutls_pkcs1_rsa_encrypt(gnutls_datum * ciphertext,
 
 		if (params_len < RSA_PRIVATE_PARAMS) {
 			gnutls_assert();
+			gnutls_free(edata);
 			return GNUTLS_E_INTERNAL_ERROR;
 		}
 		
@@ -131,6 +135,7 @@ int _gnutls_pkcs1_rsa_encrypt(gnutls_datum * ciphertext,
 		break;
 	default:
 		gnutls_assert();
+		gnutls_free(edata);
 		return GNUTLS_E_INTERNAL_ERROR;
 	}
 
@@ -282,6 +287,7 @@ int _gnutls_pkcs1_rsa_decrypt(gnutls_datum * plaintext,
 		break;
 	default:
 		gnutls_assert();
+		gnutls_free(edata);
 		return GNUTLS_E_INTERNAL_ERROR;
 	}
 	i++;
@@ -409,7 +415,7 @@ int _gnutls_dsa_sign(gnutls_datum * signature, const gnutls_datum *hash,
 	}
 
 	ret = _gnutls_pk_sign(GCRY_PK_DSA, rs, mdata, params, params_len);
-	/* res now holds r,s */
+	/* rs[0], rs[1] now hold r,s */
 	_gnutls_mpi_release(&mdata);
 
 	if (ret < 0) {
@@ -519,7 +525,7 @@ int _gnutls_dsa_verify( const gnutls_datum* vdata, const gnutls_datum *sig_value
  */
 static int _gnutls_pk_encrypt(int algo, GNUTLS_MPI * resarr, GNUTLS_MPI data, GNUTLS_MPI * pkey, int pkey_len)
 {
-	GCRY_SEXP s_ciph, s_data, s_pkey;
+	gcry_sexp_t s_ciph, s_data, s_pkey;
 	int rc=-1;
 
 	/* make a sexp from pkey */
@@ -558,7 +564,7 @@ static int _gnutls_pk_encrypt(int algo, GNUTLS_MPI * resarr, GNUTLS_MPI data, GN
 		return GNUTLS_E_PK_ENCRYPTION_FAILED;
 
 	} else {		/* add better error handling or make gnupg use S-Exp directly */
-		GCRY_SEXP list = gcry_sexp_find_token(s_ciph, "a", 0);
+		gcry_sexp_t list = gcry_sexp_find_token(s_ciph, "a", 0);
 		if (list == NULL) {
 			gnutls_assert();
 			gcry_sexp_release(s_ciph);
@@ -579,9 +585,10 @@ static int _gnutls_pk_encrypt(int algo, GNUTLS_MPI * resarr, GNUTLS_MPI data, GN
 	return rc;
 }
 
-static int _gnutls_pk_decrypt(int algo, GNUTLS_MPI * resarr, GNUTLS_MPI data, GNUTLS_MPI * pkey, int pkey_len)
+static 
+int _gnutls_pk_decrypt(int algo, GNUTLS_MPI * resarr, GNUTLS_MPI data, GNUTLS_MPI * pkey, int pkey_len)
 {
-	GCRY_SEXP s_plain, s_data, s_pkey;
+	gcry_sexp_t s_plain, s_data, s_pkey;
 	int rc=-1;
 
 	/* make a sexp from pkey */
@@ -618,9 +625,9 @@ static int _gnutls_pk_decrypt(int algo, GNUTLS_MPI * resarr, GNUTLS_MPI data, GN
 
 	if (rc != 0) {
 		gnutls_assert();
-		return GNUTLS_E_PK_ENCRYPTION_FAILED;
+		return GNUTLS_E_PK_DECRYPTION_FAILED;
 
-	} else {		/* add better error handling or make gnupg use S-Exp directly */
+	} else { /* add better error handling or make gnupg use S-Exp directly */
 		resarr[0] = gcry_sexp_nth_mpi(s_plain, 0, 0);
 
 		if (resarr[0] == NULL) {
@@ -640,7 +647,7 @@ static int _gnutls_pk_decrypt(int algo, GNUTLS_MPI * resarr, GNUTLS_MPI data, GN
 static 
 int _gnutls_pk_sign(int algo, GNUTLS_MPI* data, GNUTLS_MPI hash, GNUTLS_MPI * pkey, int pkey_len)
 {
-	GCRY_SEXP s_hash, s_key, s_sig;
+	gcry_sexp_t s_hash, s_key, s_sig;
 	int rc=-1;
 
 	/* make a sexp from pkey */
@@ -692,7 +699,7 @@ int _gnutls_pk_sign(int algo, GNUTLS_MPI* data, GNUTLS_MPI hash, GNUTLS_MPI * pk
 		return GNUTLS_E_PK_SIGN_FAILED;
 
 	} else {
-		GCRY_SEXP list;
+		gcry_sexp_t list;
 		
 		if (algo==GCRY_PK_DSA) {
 			list = gcry_sexp_find_token( s_sig, "r" , 0);
@@ -734,7 +741,7 @@ int _gnutls_pk_sign(int algo, GNUTLS_MPI* data, GNUTLS_MPI hash, GNUTLS_MPI * pk
 
 static int _gnutls_pk_verify(int algo, GNUTLS_MPI hash, GNUTLS_MPI* data, GNUTLS_MPI *pkey, int pkey_len)
 {
-	GCRY_SEXP s_sig, s_hash, s_pkey;
+	gcry_sexp_t s_sig, s_hash, s_pkey;
 	int rc=-1;
 
 	/* make a sexp from pkey */
