@@ -67,7 +67,7 @@ void _gnutls_set_current_version(gnutls_session session, gnutls_protocol_version
   * if there are pending data to socket buffer. Used only   
   * if you have changed the default low water value (default is 1).
   * Normally you will not need that function. 
-  * This function is only usefull if using berkeley style sockets.
+  * This function is only useful if using berkeley style sockets.
   * Otherwise it must be called and set lowat to zero.
   *
   **/
@@ -163,7 +163,8 @@ void gnutls_transport_get_ptr2(gnutls_session session,
   * you should wait for an EOF from the peer.
   * GNUTLS_SHUT_WR sends an alert containing a close request.
   *
-  * This function may also return GNUTLS_E_AGAIN, or GNUTLS_E_INTERRUPTED.
+  * This function may also return GNUTLS_E_AGAIN or GNUTLS_E_INTERRUPTED; cf.
+  * gnutls_record_get_direction().
   *
   **/
 int gnutls_bye( gnutls_session session, gnutls_close_request how)
@@ -225,7 +226,7 @@ static int _gnutls_session_is_valid( gnutls_session session) {
 }
 
 /* Copies the record version into the headers. The 
- * version, must have 2 bytes at least.
+ * version must have 2 bytes at least.
  */
 inline static void copy_record_version( gnutls_session session, HandshakeType htype, 
 	opaque version[2])
@@ -285,7 +286,7 @@ ssize_t _gnutls_create_empty_record( gnutls_session session, ContentType type,
 	return retval;
 }
 
-/* This function behave exactly like write(). The only difference is 
+/* This function behaves exactly like write(). The only difference is
  * that it accepts, the gnutls_session and the ContentType of data to
  * send (if called by the user the Content is specific)
  * It is intended to transfer data, under the current session.    
@@ -417,8 +418,8 @@ ssize_t _gnutls_send_int( gnutls_session session, ContentType type, HandshakeTyp
 
 	if ( ret != cipher_size + erecord_size) {
 		if ( ret < 0 && gnutls_error_is_fatal(ret)==0) {
-			/* If we have sent any data then return
-			 * that value.
+			/* If we have sent any data then just return
+			 * the error value. Do not invalidate the session.
 			 */
 			gnutls_assert();
 			return ret;
@@ -474,12 +475,12 @@ static int _gnutls_check_recv_type( ContentType recv_type) {
 }
 
 
-/* Checks if there are pending data into the record buffers. If there are
+/* Checks if there are pending data in the record buffers. If there are
  * then it copies the data.
  */
 static int _gnutls_check_buffers( gnutls_session session, ContentType type, opaque* data, int sizeofdata) {
-	int ret = 0, ret2=0;
 	if ( (type == GNUTLS_APPLICATION_DATA || type == GNUTLS_HANDSHAKE) && _gnutls_record_buffer_get_size(type, session) > 0) {
+		int ret, ret2;
 		ret = _gnutls_record_buffer_get(type, session, data, sizeofdata);
 		if (ret < 0) {
 			gnutls_assert();
@@ -572,7 +573,7 @@ static int _gnutls_check_record_version( gnutls_session session, HandshakeType h
 }
 
 /* This function will check if the received record type is
- * the one we actually expecting for.
+ * the one we actually expect.
  */
 static int _gnutls_record_check_type( gnutls_session session, ContentType recv_type,
 	ContentType type, HandshakeType htype, opaque* data, int data_size) {
@@ -676,8 +677,8 @@ static int _gnutls_record_check_type( gnutls_session session, ContentType recv_t
 
 #define MAX_EMPTY_PACKETS_SEQUENCE 4
 
-/* This function behave exactly like read(). The only difference is 
- * that it accepts, the gnutls_session and the ContentType of data to
+/* This function behaves exactly like read(). The only difference is
+ * that it accepts the gnutls_session and the ContentType of data to
  * send (if called by the user the Content is Userdata only)
  * It is intended to receive data, under the current session.
  */
@@ -695,6 +696,10 @@ ssize_t _gnutls_recv_int( gnutls_session session, ContentType type, HandshakeTyp
 	uint16 header_size;
 	int empty_packet = 0;
 
+	if (sizeofdata == 0 || data == NULL) {
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
 	begin:
 	
 	if (empty_packet > MAX_EMPTY_PACKETS_SEQUENCE) {
@@ -707,10 +712,6 @@ ssize_t _gnutls_recv_int( gnutls_session session, ContentType type, HandshakeTyp
 	header_size = RECORD_HEADER_SIZE;
 	ret = 0;
 
-	if (sizeofdata == 0 || data == NULL) {
-		return GNUTLS_E_INVALID_REQUEST;
-	}
-
 	if ( _gnutls_session_is_valid(session)!=0 || session->internals.may_read!=0) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_SESSION;
@@ -877,7 +878,7 @@ ssize_t _gnutls_recv_int( gnutls_session session, ContentType type, HandshakeTyp
 	 * Actually this code is called if we just received
 	 * an empty packet. An empty TLS packet is usually
 	 * sent to protect some vulnerabilities in the CBC mode.
-	 * In that case we go to the begining and start reading
+	 * In that case we go to the beginning and start reading
 	 * the next packet.
 	 */
 	if (ret==0) {
@@ -900,10 +901,10 @@ ssize_t _gnutls_recv_int( gnutls_session session, ContentType type, HandshakeTyp
   * error codes.
   *
   * If the EINTR is returned by the internal push function (write())
-  * then GNUTLS_E_INTERRUPTED, will be returned. If GNUTLS_E_INTERRUPTED or
-  * GNUTLS_E_AGAIN is returned you must call this function again, with the 
-  * same parameters. Otherwise the write operation will be 
-  * corrupted and the connection will be terminated.
+  * then GNUTLS_E_INTERRUPTED will be returned. If GNUTLS_E_INTERRUPTED or
+  * GNUTLS_E_AGAIN is returned, you must call this function again, with the
+  * same parameters; cf. gnutls_record_get_direction(). Otherwise the write
+  * operation will be corrupted and the connection will be terminated.
   *
   * This function may accept a NULL pointer for data, and 0 for size, if
   * and only if the previous send was interrupted for some reason.
