@@ -58,7 +58,7 @@ int _gnutls_rsa_generate_params(GNUTLS_MPI* resarr, int bits)
 {
 
 	int ret;
-	GCRY_SEXP parms, key, list;
+	gcry_sexp_t parms, key, list;
 
 	ret = gcry_sexp_build( &parms, NULL, "(genkey(rsa(nbits %d)))", bits);
 	if (ret != 0) {
@@ -209,7 +209,7 @@ void gnutls_rsa_params_deinit(gnutls_rsa_params rsa_params)
   * 
   * Note that if the parameters are to be used in export cipher suites the 
   * bits value should be 512 or less.
-  * Also note that the generation of new RSA parameters is only usefull
+  * Also note that the generation of new RSA parameters is only useful
   * to servers. Clients use the parameters sent by the server, thus it's
   * no use calling this in client side.
   *
