@@ -193,7 +193,8 @@ int gnutls_init(gnutls_session * session, gnutls_connection_end con_end)
 
 	(*session)->key = gnutls_calloc(1, sizeof(struct GNUTLS_KEY_INT));
 	if ( (*session)->key == NULL) {
-		gnutls_free( *session);
+		cleanup_session:
+		gnutls_free( *session); *session = NULL;
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 
@@ -206,10 +207,14 @@ int gnutls_init(gnutls_session * session, gnutls_connection_end con_end)
 	gnutls_handshake_set_max_packet_length( (*session), MAX_HANDSHAKE_PACKET_SIZE);
 
 	/* Allocate a minimum size for recv_data 
-	 * This is allocated in order to avoid small messages, makeing
+	 * This is allocated in order to avoid small messages, making
 	 * the receive procedure slow.
 	 */
 	(*session)->internals.record_recv_buffer.data = gnutls_malloc(INITIAL_RECV_BUFFER_SIZE);
+	if ( (*session)->internals.record_recv_buffer.data == NULL) {
+		gnutls_free((*session)->key);
+		goto cleanup_session;
+	}
 
 	/* set the socket pointers to -1;
 	 */
@@ -310,8 +315,6 @@ void _gnutls_deinit(gnutls_session session)
 
 	memset( session, 0, sizeof(struct gnutls_session_int));
 	gnutls_free(session);
-
-	return;
 }
 
 /**
@@ -536,7 +539,7 @@ void gnutls_record_set_cbc_protection(gnutls_session session, int prot)
   * are not yet defined in any RFC or even internet draft.
   *
   * Enabling the private ciphersuites when talking to other than gnutls
-  * servers and clients, may cause interoperability problems.
+  * servers and clients may cause interoperability problems.
   *
   **/
 void gnutls_handshake_set_private_extensions(gnutls_session session, int allow)
@@ -635,7 +638,6 @@ int i;
 	for (i = 0; i < length; i++) {
 		o1[i] ^= o2[i];
 	}
-	return ;
 }
 
 
@@ -772,11 +774,14 @@ void gnutls_session_set_ptr(gnutls_session session, void* ptr)
   * @session: is a a &gnutls_session structure.
   *
   * This function provides information about the internals of the record
-  * protocol and is only useful if any gnutls function call was 
-  * interrupted for some reason.
-  *
-  * Returns 0 if the function was interrupted while receiving data, and 
-  * 1 otherwise. 
+  * protocol and is only useful if a prior gnutls function call (e.g.
+  * gnutls_handshake()) was interrupted for some reason, that is, if a function
+  * returned GNUTLS_E_INTERRUPTED or GNUTLS_E_AGAIN. In such a case, you might
+  * want to call select() (or poll()) before calling the interrupted gnutls
+  * function again. To tell you whether a file descriptor should be selected
+  * for either reading or writing, gnutls_record_get_direction() returns 0 if
+  * the interrupted function was trying to read data, and 1 if it was trying to
+  * write data.
   *
   **/
 int gnutls_record_get_direction(gnutls_session session) {
