@@ -480,12 +480,14 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[]={
   {0,1,"6"},
   {"X520countryName",1612709890,"PrintableString"},
   {0,1048586,"2"},
-  {"pkcs-9",1879048204,0},
+  {"pkcs",1879048204,0},
   {"iso",1073741825,"1"},
   {"member-body",1073741825,"2"},
   {"us",1073741825,"840"},
   {"rsadsi",1073741825,"113549"},
-  {"pkcs",1073741825,"1"},
+  {"pkcs",1,"1"},
+  {"pkcs-9",1879048204,0},
+  {0,1073741825,"pkcs"},
   {0,1,"9"},
   {"emailAddress",1880096780,"AttributeType"},
   {0,1073741825,"pkcs-9"},
@@ -576,11 +578,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[]={
   {"parameters",541081613,0},
   {"algorithm",1,0},
   {"pkcs-1",1879048204,0},
-  {"iso",1073741825,"1"},
-  {"member-body",1073741825,"2"},
-  {"us",1073741825,"840"},
-  {"rsadsi",1073741825,"113549"},
-  {"pkcs",1073741825,"1"},
+  {0,1073741825,"pkcs"},
   {0,1,"1"},
   {"rsaEncryption",1879048204,0},
   {0,1073741825,"pkcs-1"},
@@ -862,43 +860,47 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[]={
   {"ub-terminal-id-length",1342177283,"24"},
   {"ub-unformatted-address-length",1342177283,"180"},
   {"ub-x121-address-length",1342177283,"16"},
-  {"ContentInfo",1610612741,0},
-  {"contentType",1073741826,"ContentType"},
+  {"pkcs-7-ContentInfo",1610612741,0},
+  {"contentType",1073741826,"pkcs-7-ContentType"},
   {"content",541073421,0},
   {0,1073743880,"0"},
   {"contentType",1,0},
-  {"ContentType",1073741836,0},
-  {"SignedData",1610612741,0},
-  {"version",1073741826,"CMSVersion"},
-  {"digestAlgorithms",1073741826,"DigestAlgorithmIdentifiers"},
-  {"encapContentInfo",1073741826,"EncapsulatedContentInfo"},
-  {"certificates",1610637314,"CertificateSet"},
+  {"pkcs-7-DigestInfo",1610612741,0},
+  {"digestAlgorithm",1073741826,"pkcs-7-DigestAlgorithmIdentifier"},
+  {"digest",2,"pkcs-7-Digest"},
+  {"pkcs-7-Digest",1073741831,0},
+  {"pkcs-7-ContentType",1073741836,0},
+  {"pkcs-7-SignedData",1610612741,0},
+  {"version",1073741826,"pkcs-7-CMSVersion"},
+  {"digestAlgorithms",1073741826,"pkcs-7-DigestAlgorithmIdentifiers"},
+  {"encapContentInfo",1073741826,"pkcs-7-EncapsulatedContentInfo"},
+  {"certificates",1610637314,"pkcs-7-CertificateSet"},
   {0,4104,"0"},
-  {"crls",1610637314,"CertificateRevocationLists"},
+  {"crls",1610637314,"pkcs-7-CertificateRevocationLists"},
   {0,4104,"1"},
-  {"signerInfos",2,"SignerInfos"},
-  {"CMSVersion",1610874883,0},
+  {"signerInfos",2,"pkcs-7-SignerInfos"},
+  {"pkcs-7-CMSVersion",1610874883,0},
   {"v0",1073741825,"0"},
   {"v1",1073741825,"1"},
   {"v2",1073741825,"2"},
   {"v3",1073741825,"3"},
   {"v4",1,"4"},
-  {"DigestAlgorithmIdentifiers",1610612751,0},
-  {0,2,"DigestAlgorithmIdentifier"},
-  {"DigestAlgorithmIdentifier",1073741826,"AlgorithmIdentifier"},
-  {"EncapsulatedContentInfo",1610612741,0},
-  {"eContentType",1073741826,"ContentType"},
+  {"pkcs-7-DigestAlgorithmIdentifiers",1610612751,0},
+  {0,2,"pkcs-7-DigestAlgorithmIdentifier"},
+  {"pkcs-7-DigestAlgorithmIdentifier",1073741826,"AlgorithmIdentifier"},
+  {"pkcs-7-EncapsulatedContentInfo",1610612741,0},
+  {"eContentType",1073741826,"pkcs-7-ContentType"},
   {"eContent",536895495,0},
   {0,2056,"0"},
-  {"CertificateRevocationLists",1610612751,0},
+  {"pkcs-7-CertificateRevocationLists",1610612751,0},
   {0,13,0},
-  {"CertificateChoices",1610612754,0},
+  {"pkcs-7-CertificateChoices",1610612754,0},
   {"certificate",13,0},
-  {"CertificateSet",1610612751,0},
-  {0,2,"CertificateChoices"},
-  {"SignerInfos",1610612751,0},
+  {"pkcs-7-CertificateSet",1610612751,0},
+  {0,2,"pkcs-7-CertificateChoices"},
+  {"pkcs-7-SignerInfos",1610612751,0},
   {0,13,0},
-  {"CertificationRequestInfo",1610612741,0},
+  {"pkcs-10-CertificationRequestInfo",1610612741,0},
   {"version",1610874883,0},
   {"v1",1,"0"},
   {"subject",1073741826,"Name"},
@@ -907,40 +909,51 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[]={
   {0,4104,"0"},
   {"Attributes",1610612751,0},
   {0,2,"Attribute"},
-  {"CertificationRequest",1610612741,0},
-  {"certificationRequestInfo",1073741826,"CertificationRequestInfo"},
+  {"pkcs-10-CertificationRequest",1610612741,0},
+  {"certificationRequestInfo",1073741826,"pkcs-10-CertificationRequestInfo"},
   {"signatureAlgorithm",1073741826,"AlgorithmIdentifier"},
   {"signature",6,0},
   {"pkcs-9-ub-challengePassword",1342177283,"255"},
-  {"challengePassword",1880096780,"AttributeType"},
+  {"pkcs-9-certTypes",1879048204,0},
+  {0,1073741825,"pkcs-9"},
+  {0,1,"22"},
+  {"pkcs-9-crlTypes",1879048204,0},
+  {0,1073741825,"pkcs-9"},
+  {0,1,"23"},
+  {"pkcs-9-challengePassword",1880096780,"AttributeType"},
   {0,1073741825,"pkcs-9"},
   {0,1,"7"},
-  {"Pkcs9challengePassword",1610612754,0},
+  {"pkcs-9-challengePassword",1610612754,0},
   {"printableString",1612709890,"PrintableString"},
   {"pkcs-9-ub-challengePassword",524298,"1"},
   {"utf8String",538968066,"UTF8String"},
   {"pkcs-9-ub-challengePassword",524298,"1"},
-  {"PrivateKeyInfo",1610612741,0},
-  {"version",1073741826,"Version"},
+  {"pkcs-9-at-localKeyId",1879048204,0},
+  {0,1073741825,"pkcs-9"},
+  {0,1,"21"},
+  {"pkcs-9-localKeyId",1073741831,0},
+  {"pkcs-9-at-friendlyName",1879048204,0},
+  {0,1073741825,"pkcs-9"},
+  {0,1,"20"},
+  {"pkcs-9-friendlyName",1612709890,"BMPString"},
+  {"255",524298,"1"},
+  {"pkcs-8-PrivateKeyInfo",1610612741,0},
+  {"version",1073741826,"pkcs-8-Version"},
   {"privateKeyAlgorithm",1073741826,"AlgorithmIdentifier"},
-  {"privateKey",1073741826,"PrivateKey"},
+  {"privateKey",1073741826,"pkcs-8-PrivateKey"},
   {"attributes",536895490,"Attributes"},
   {0,4104,"0"},
-  {"Version",1610874883,0},
+  {"pkcs-8-Version",1610874883,0},
   {"v1",1,"0"},
-  {"PrivateKey",1073741831,0},
-  {"Attributes",1610612751,0},
+  {"pkcs-8-PrivateKey",1073741831,0},
+  {"pkcs-8-Attributes",1610612751,0},
   {0,2,"Attribute"},
-  {"EncryptedPrivateKeyInfo",1610612741,0},
+  {"pkcs-8-EncryptedPrivateKeyInfo",1610612741,0},
   {"encryptionAlgorithm",1073741826,"AlgorithmIdentifier"},
-  {"encryptedData",2,"EncryptedData"},
-  {"EncryptedData",1073741831,0},
+  {"encryptedData",2,"pkcs-8-EncryptedData"},
+  {"pkcs-8-EncryptedData",1073741831,0},
   {"pkcs-5",1879048204,0},
-  {"iso",1073741825,"1"},
-  {"member-body",1073741825,"2"},
-  {"us",1073741825,"840"},
-  {"rsadsi",1073741825,"113549"},
-  {"pkcs",1073741825,"1"},
+  {0,1073741825,"pkcs"},
   {0,1,"5"},
   {"pkcs-5-encryptionAlgorithm",1879048204,0},
   {"iso",1073741825,"1"},
@@ -962,7 +975,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[]={
   {"pkcs-5-id-PBKDF2",1879048204,0},
   {0,1073741825,"pkcs-5"},
   {0,1,"12"},
-  {"pkcs-5-PBKDF2-params",536870917,0},
+  {"pkcs-5-PBKDF2-params",1610612741,0},
   {"salt",1610612754,0},
   {"specified",1073741831,0},
   {"otherSource",2,"AlgorithmIdentifier"},
@@ -971,5 +984,93 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[]={
   {"keyLength",1611153411,0},
   {"1",10,"MAX"},
   {"prf",16386,"AlgorithmIdentifier"},
+  {"pkcs-12",1879048204,0},
+  {0,1073741825,"pkcs"},
+  {0,1,"12"},
+  {"pkcs-12-PFX",1610612741,0},
+  {"version",1610874883,0},
+  {"v3",1,"3"},
+  {"authSafe",1073741826,"pkcs-7-ContentInfo"},
+  {"macData",16386,"pkcs-12-MacData"},
+  {"pkcs-12-PbeParams",1610612741,0},
+  {"salt",1073741831,0},
+  {"iterations",3,0},
+  {"pkcs-12-MacData",1610612741,0},
+  {"mac",1073741826,"pkcs-7-DigestInfo"},
+  {"macSalt",1073741831,0},
+  {"iterations",536903683,0},
+  {0,9,"1"},
+  {"pkcs-12-AuthenticatedSafe",1610612747,0},
+  {0,2,"pkcs-7-ContentInfo"},
+  {"pkcs-12-SafeContents",1610612747,0},
+  {0,2,"pkcs-12-SafeBag"},
+  {"pkcs-12-SafeBag",1610612741,0},
+  {"bagId",1073741836,0},
+  {"bagValue",1614815245,0},
+  {0,1073743880,"0"},
+  {"badId",1,0},
+  {"bagAttributes",536887311,0},
+  {0,2,"pkcs-12-PKCS12Attribute"},
+  {"pkcs-12-bagtypes",1879048204,0},
+  {0,1073741825,"pkcs-12"},
+  {0,1073741825,"10"},
+  {0,1,"1"},
+  {"pkcs-12-keyBag",1879048204,0},
+  {0,1073741825,"pkcs-12-bagtypes"},
+  {0,1,"1"},
+  {"pkcs-12-pkcs8ShroudedKeyBag",1879048204,0},
+  {0,1073741825,"pkcs-12-bagtypes"},
+  {0,1,"2"},
+  {"pkcs-12-certBag",1879048204,0},
+  {0,1073741825,"pkcs-12-bagtypes"},
+  {0,1,"3"},
+  {"pkcs-12-crlBag",1879048204,0},
+  {0,1073741825,"pkcs-12-bagtypes"},
+  {0,1,"4"},
+  {"pkcs-12-KeyBag",1073741826,"pkcs-8-PrivateKeyInfo"},
+  {"pkcs-12-PKCS8ShroudedKeyBag",1073741826,"pkcs-8-EncryptedPrivateKeyInfo"},
+  {"pkcs-12-CertBag",1610612741,0},
+  {"certId",1073741836,0},
+  {"certValue",541073421,0},
+  {0,1073743880,"0"},
+  {"certId",1,0},
+  {"pkcs-12-CRLBag",1610612741,0},
+  {"crlId",1073741836,0},
+  {"crlValue",541073421,0},
+  {0,1073743880,"0"},
+  {"crlId",1,0},
+  {"pkcs-12-PKCS12Attribute",1073741826,"Attribute"},
+  {"pkcs-7-data",1879048204,0},
+  {"iso",1073741825,"1"},
+  {"member-body",1073741825,"2"},
+  {"us",1073741825,"840"},
+  {"rsadsi",1073741825,"113549"},
+  {"pkcs",1073741825,"1"},
+  {"pkcs7",1073741825,"7"},
+  {0,1,"1"},
+  {"pkcs-7-encryptedData",1879048204,0},
+  {"iso",1073741825,"1"},
+  {"member-body",1073741825,"2"},
+  {"us",1073741825,"840"},
+  {"rsadsi",1073741825,"113549"},
+  {"pkcs",1073741825,"1"},
+  {"pkcs7",1073741825,"7"},
+  {0,1,"6"},
+  {"pkcs-7-Data",1073741831,0},
+  {"pkcs-7-EncryptedData",1610612741,0},
+  {"version",1073741826,"pkcs-7-CMSVersion"},
+  {"encryptedContentInfo",1073741826,"pkcs-7-EncryptedContentInfo"},
+  {"unprotectedAttrs",536895490,"pkcs-7-UnprotectedAttributes"},
+  {0,4104,"1"},
+  {"pkcs-7-EncryptedContentInfo",1610612741,0},
+  {"contentType",1073741826,"pkcs-7-ContentType"},
+  {"contentEncryptionAlgorithm",1073741826,"pkcs-7-ContentEncryptionAlgorithmIdentifier"},
+  {"encryptedContent",536895490,"pkcs-7-EncryptedContent"},
+  {0,4104,"0"},
+  {"pkcs-7-ContentEncryptionAlgorithmIdentifier",1073741826,"AlgorithmIdentifier"},
+  {"pkcs-7-EncryptedContent",1073741831,0},
+  {"pkcs-7-UnprotectedAttributes",538968079,0},
+  {"MAX",1074266122,"1"},
+  {0,2,"Attribute"},
   {0,0,0}
 };
