@@ -8,6 +8,7 @@ void _gnutls_int2str(unsigned int k, char *data);
 #define PEM_X509_CERT "X509 CERTIFICATE"
 #define PEM_X509_CERT2 "CERTIFICATE"
 #define PEM_PKCS7 "PKCS7"
+#define PEM_PKCS12 "PKCS12"
 
 #define PKIX1_RSA_OID "1.2.840.113549.1.1.1"
 #define DSA_OID "1.2.840.10040.4.1"
@@ -41,7 +42,18 @@ time_t _gnutls_x509_get_time(ASN1_TYPE c2, const char *when);
 gnutls_x509_subject_alt_name _gnutls_x509_san_find_type( char* str_type);
 
 int _gnutls_x509_der_encode_and_copy( ASN1_TYPE src, const char* src_name,
-	ASN1_TYPE dest, const char* dest_name);
+	ASN1_TYPE dest, const char* dest_name, int str);
+int _gnutls_x509_der_encode( ASN1_TYPE src, const char* src_name,
+        gnutls_datum *res, int str);
+
 int _gnutls_x509_export_int( ASN1_TYPE asn1_data,
 	gnutls_x509_crt_fmt format, char* pem_header,
 	int tmp_buf_size, unsigned char* output_data, int* output_data_size);
+
+int _gnutls_x509_read_value( ASN1_TYPE c, const char* root, gnutls_datum *ret, int str);
+int _gnutls_x509_write_value( ASN1_TYPE c, const char* root, const gnutls_datum* data, int str);
+
+int _gnutls_x509_encode_and_write_attribute( const char* given_oid, ASN1_TYPE asn1_struct, 
+	const char* where, const unsigned char* data, int sizeof_data, int multi);
+int _gnutls_x509_decode_and_read_attribute(ASN1_TYPE asn1_struct, const char* where,
+        char* oid, int oid_size, gnutls_datum* value, int multi);
