@@ -91,7 +91,7 @@ int _gnutls_x509_parse_dn(ASN1_TYPE asn1_struct,
 	char tmpbuffer2[64];
 	char tmpbuffer3[64];
 	char counter[MAX_INT_DIGITS];
-	char value[200];
+	char value[256];
 	char escaped[256];
 	const char *ldap_desc;
 	char oid[128];
@@ -491,8 +491,7 @@ int _gnutls_x509_encode_and_write_attribute( const char* given_oid, ASN1_TYPE as
 const char *val_name;
 char tmp[128];
 ASN1_TYPE c2;
-opaque *der;
-int der_len, result;
+int result;
 
 
 	/* Find how to encode the data.
@@ -514,7 +513,7 @@ int der_len, result;
 
 	tmp[0] = 0;
 
-	if (_gnutls_x509_oid_data_choice( given_oid) == 1) {
+	if ((result=_gnutls_x509_oid_data_choice( given_oid)) > 0) {
 		char* string_type;
 		int i;
 
@@ -550,19 +549,6 @@ int der_len, result;
 		return _gnutls_asn2err(result);
 	}
 
-	der_len = 0;
-	asn1_der_coding( c2, "", NULL, &der_len, NULL);
-
-	der = gnutls_alloca( der_len);
-	result = asn1_der_coding( c2, "", der, &der_len, NULL);
-	
-	asn1_delete_structure( &c2);
-
-	if (result != ASN1_SUCCESS) {
-		gnutls_assert();
-		gnutls_afree(der);
-		return _gnutls_asn2err(result);
-	}
 	
 	/* write the data (value)
 	 */
@@ -576,7 +562,6 @@ int der_len, result;
 		result = asn1_write_value( asn1_struct, tmp, "NEW", 1);
 		if (result != ASN1_SUCCESS) {
 			gnutls_assert();
-			gnutls_afree(der);
 			return _gnutls_asn2err(result);
 		}
 
@@ -584,13 +569,10 @@ int der_len, result;
 	
 	}
 
-	result = asn1_write_value( asn1_struct, tmp, der, der_len);
-
-	gnutls_afree(der);
-
-	if (result != ASN1_SUCCESS) {
+	result = _gnutls_x509_der_encode_and_copy( c2, "", asn1_struct, tmp, 0);
+	if (result < 0) {
 		gnutls_assert();
-		return _gnutls_asn2err(result);
+		return result;
 	}
 
 	/* write the type
@@ -607,6 +589,47 @@ int der_len, result;
 	return 0;
 }
 
+/* Decodes an X.509 Attribute (if multi==1) or an AttributeTypeAndValue
+ * otherwise.
+ */
+int _gnutls_x509_decode_and_read_attribute(ASN1_TYPE asn1_struct, const char* where,
+	char* oid, int oid_size, gnutls_datum* value, int multi) 
+{
+char tmpbuffer[128];
+int len, result;
+
+	/* Read the OID 
+	 */
+	_gnutls_str_cpy(tmpbuffer, sizeof(tmpbuffer), where);
+	_gnutls_str_cat(tmpbuffer, sizeof(tmpbuffer), ".type");
+
+	len = oid_size - 1;
+	result = asn1_read_value(asn1_struct, tmpbuffer, oid, &len);
+
+	if (result != ASN1_SUCCESS) {
+		gnutls_assert();
+		result = _gnutls_asn2err(result);
+		return result;
+	}
+
+	/* Read the Value 
+	 */
+
+	_gnutls_str_cpy(tmpbuffer, sizeof(tmpbuffer), where);
+	_gnutls_str_cat(tmpbuffer, sizeof(tmpbuffer), ".value");
+
+	if (multi)
+		_gnutls_str_cat(tmpbuffer, sizeof(tmpbuffer), "s.?1"); /* .values.?1 */
+
+	result = _gnutls_x509_read_value( asn1_struct, tmpbuffer, value, 0);
+	if (result < 0) {
+		gnutls_assert();
+		return result;
+	}
+
+	return 0;
+
+}
 
 /* Sets an X509 DN in the asn1_struct, and puts the given OID in the DN.
  * The input is assumed to be raw data.
