@@ -133,7 +133,7 @@ inline static int decode(uint8 * result, const uint8 * data)
 	return ret;
 }
 
-/* encodes data and puts the result into result (localy alocated)
+/* encodes data and puts the result into result (locally allocated)
  * The result_size is the return value
  */
 int _gnutls_base64_encode(const uint8 * data, size_t data_size, uint8 ** result)
@@ -161,7 +161,7 @@ int _gnutls_base64_encode(const uint8 * data, size_t data_size, uint8 ** result)
 	return ret;
 }
 
-/* encodes data and puts the result into result (localy alocated)
+/* encodes data and puts the result into result (locally allocated)
  * The result_size is the return value
  */
 int _gnutls_fbase64_encode(const char *msg, const uint8 * data, int data_size,
@@ -173,13 +173,14 @@ int _gnutls_fbase64_encode(const char *msg, const uint8 * data, int data_size,
 	uint8 top[80];
 	uint8 bottom[80];
 	int pos;
+	size_t msglen = strlen(msg);
+
+	if (msglen > 50)
+		return GNUTLS_E_BASE64_ENCODING_ERROR;
 
 	memset(bottom, 0, sizeof(bottom));
 	memset(top, 0, sizeof(top));
 
-	if (strlen(msg) > 50)
-		return GNUTLS_E_MEMORY_ERROR;
-
 	strcat(top, "-----BEGIN "); /* Flawfinder: ignore */
 	strcat(top, msg); /* Flawfinder: ignore */
 	strcat(top, "-----"); /* Flawfinder: ignore */
@@ -188,20 +189,20 @@ int _gnutls_fbase64_encode(const char *msg, const uint8 * data, int data_size,
 	strcat(bottom, msg); /* Flawfinder: ignore */
 	strcat(bottom, "-----\n"); /* Flawfinder: ignore */
 
-	ret = B64FSIZE( strlen(msg), data_size);
+	ret = B64FSIZE( msglen, data_size);
 
 	(*result) = gnutls_calloc(1, ret + 1);
 	if ((*result) == NULL)
 		return GNUTLS_E_MEMORY_ERROR;
 
-	strcat(*result, top); /* Flawfinder: ignore */
+	strcpy(*result, top); /* Flawfinder: ignore */
 	pos = strlen(top);
 
 	for (i = j = 0; i < data_size; i += 3, j += 4) {
 		tmp = encode(tmpres, &data[i], data_size - i);
 		if (tmp == -1) {
-			gnutls_free( (*result));
-			return GNUTLS_E_MEMORY_ERROR;
+			gnutls_free( (*result)); *result = NULL;
+			return GNUTLS_E_BASE64_ENCODING_ERROR;
 		}
 		ptr = &(*result)[j + pos];
 
@@ -287,23 +288,19 @@ int gnutls_pem_base64_encode_alloc( const char* msg, const gnutls_datum *data,
 opaque* ret;
 int size;
 
+	if (result==NULL) return GNUTLS_E_INVALID_REQUEST;
+
 	size = _gnutls_fbase64_encode( msg, data->data, data->size, &ret);
 	if (size < 0)
 		return size;
 
-	if (result==NULL) {
-		gnutls_free(ret);
-		return GNUTLS_E_INVALID_REQUEST;
-	} else {
-		result->data = ret;
-	        result->size = size;
-	}
-
+	result->data = ret;
+	result->size = size;
 	return 0;
 }
 
 
-/* decodes data and puts the result into result (localy alocated)
+/* decodes data and puts the result into result (locally allocated)
  * The result_size is the return value
  */
 int _gnutls_base64_decode(const uint8 * data, size_t data_size, uint8 ** result)
@@ -313,22 +310,19 @@ int _gnutls_base64_decode(const uint8 * data, size_t data_size, uint8 ** result)
 	uint8 tmpres[3];
 
 	est = ((data_size * 3) / 4) + 1;
-	ret = 0;
-
 	(*result) = gnutls_malloc(est);
 	if ((*result) == NULL)
 		return GNUTLS_E_MEMORY_ERROR;
 
-	for (i = j = 0; i < data_size; i += 4) {
+	ret = 0;
+	for (i = j = 0; i < data_size; i += 4, j += 3) {
 		tmp = decode(tmpres, &data[i]);
 		if (tmp < 0) {
-			gnutls_free( *result);
+			gnutls_free( *result); *result = NULL;
 			return tmp;
 		}
 		memcpy(&(*result)[j], tmpres, tmp);
 		ret += tmp;
-
-		j += 3;
 	}
 	return ret;
 }
@@ -342,7 +336,7 @@ inline static int cpydata(const uint8 * data, int data_size, uint8 ** result)
 
 	(*result) = gnutls_malloc(data_size);
 	if (*result == NULL)
-		return -1;
+		return GNUTLS_E_MEMORY_ERROR;
 
 	for (j = i = 0; i < data_size; i++) {
 		if (data[i] == '\n' || data[i] == '\r')
@@ -359,12 +353,13 @@ inline static int cpydata(const uint8 * data, int data_size, uint8 ** result)
  * The result_size is the return value
  */
 #define ENDSTR "-----\n"
+#define ENDSTR2 "-----\r\n"
 int _gnutls_fbase64_decode( const opaque* header, const opaque * data, size_t data_size,
 			   uint8 ** result)
 {
 	int ret;
-	char top[] = "-----BEGIN ";
-	char bottom[] = "\n-----END ";
+	const char top[] = "-----BEGIN ";
+	const char bottom[] = "\n-----END ";
 	uint8 *rdata;
 	int rdata_size;
 	uint8 *kdata;
@@ -391,6 +386,10 @@ int _gnutls_fbase64_decode( const opaque* header, const opaque * data, size_t da
 	}
 
 	kdata = strnstr( rdata, ENDSTR, data_size);
+	/* allow CR as well.
+	 */
+	if (kdata==NULL) kdata = strnstr( rdata, ENDSTR2, data_size);
+
 	if (kdata==NULL) {
 		gnutls_assert();
 		_gnutls_x509_log( "Could not find '%s'\n", ENDSTR);
@@ -420,8 +419,14 @@ int _gnutls_fbase64_decode( const opaque* header, const opaque * data, size_t da
 
 	kdata_size = cpydata(rdata, rdata_size, &kdata);
 
+	if (kdata_size < 0) {
+		gnutls_assert();
+		return kdata_size;
+	}
+
 	if (kdata_size < 4) {
 		gnutls_assert();
+		gnutls_free(kdata);
 		return GNUTLS_E_BASE64_DECODING_ERROR;
 	}
 
@@ -493,18 +498,13 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 opaque* ret;
 int size;
 
+	if (result==NULL) return GNUTLS_E_INVALID_REQUEST;
+
 	size = _gnutls_fbase64_decode( header, b64_data->data, b64_data->size, &ret);
 	if (size < 0)
 		return size;
 
-	if (result==NULL) {
-		gnutls_free(ret);
-		return GNUTLS_E_INVALID_REQUEST;
-	} else {
-		result->data = ret;
-		result->size = size;
-	}
-
+	result->data = ret;
+	result->size = size;
 	return 0;
 }
-
