@@ -70,7 +70,7 @@ inline static int is_srp( GNUTLS_CipherSuite suite) {
 }
 
 /* returns data_size or a negative number on failure
- * data is allocated localy
+ * data is allocated locally
  */
 int _gnutls_srp_send_params( gnutls_session state, opaque* data, size_t data_size) {
 	uint len;
@@ -90,10 +90,13 @@ int _gnutls_srp_send_params( gnutls_session state, opaque* data, size_t data_siz
 		if (cred==NULL) return 0;
 
 		if (cred->username!=NULL) { /* send username */
-			len = strlen(cred->username) % 256;
+			len = strlen(cred->username);
+			
+			if (len > 255) len = 255;
+
 			if (data_size < len+1) {
 				gnutls_assert();
-				return GNUTLS_E_INVALID_REQUEST;
+				return GNUTLS_E_SHORT_MEMORY_BUFFER;
 			}
 
 			data[0] = (uint8) len;
