@@ -736,7 +736,7 @@ int main(int argc, char **argv)
 	    j->fd = accept_fd;
 
 	    j->tls_session = tls_session;
-	    gnutls_transport_set_ptr(tls_session, accept_fd);
+	    gnutls_transport_set_ptr(tls_session, (gnutls_transport_ptr)accept_fd);
 	    j->handshake_ok = 0;
 
 	    if (quiet == 0) {
@@ -1021,7 +1021,6 @@ static void wrap_db_init(void)
 
 static void wrap_db_deinit(void)
 {
-   return;
 }
 
 static int wrap_db_store(void *dbf, gnutls_datum key, gnutls_datum data)
